/*
** nis_ethers.h           Ethers cover routines for NIS+
**
** Copyright (c) 1993 Signum Support AB, Sweden
**
** This file is part of the NYS Library.
**
** The NYS Library is free software; you can redistribute it and/or
** modify it under the terms of the GNU Library General Public License as
** published by the Free Software Foundation; either version 2 of the
** License, or (at your option) any later version.
**
** The NYS Library is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** Library General Public License for more details.
** 
** You should have received a copy of the GNU Library General Public
** License along with the NYS Library; see the file COPYING.LIB.  If
** not, write to the Free Software Foundation, Inc., 675 Mass Ave,
** Cambridge, MA 02139, USA.
*/

#ifndef __NIS_ETHERS_H__
#define __NIS_ETHERS_H__

#include <sys/types.h>
#include <ethers.h>

extern void nis_setethent(void);
extern void nis_endethent(void);
extern struct ether * nis_getethent(void);
extern struct ether * nis_getethbyname(const char *name);
extern struct ether * nis_getethbyaddr(const struct ether_addr *addr);

#endif
